import React, { Component } from 'react';
import styles from './index.module.less';

export default class NumberCard extends Component {
  static defaultProps = {
    width: 10,
    height: 12,
    value: 0,
  }
  constructor(props) {
    super(props);
    this.state = {
      nextValue: props.value,
      lastValue: props.value,
    };
  }
  componentWillReceiveProps(nextProps) {
    if (nextProps.value !== this.props.value) {
      this.setState({
        lastValue: this.state.nextValue,
        nextValue: nextProps.value,
      }, () => {
        this.flipCard();
      });
    }
  }
  flipCard() {
    const flipping = this.card.animate([
      {
        transform: 'rotateX(0deg)',
      },
      {
        transform: 'rotateX(180deg)',
      },
    ], {
      duration: 1000,
    });
    flipping.onfinish = () => {
      this.setState({
        lastValue: this.state.nextValue,
      });
    };
    flipping.play();
  }
  render() {
    const { nextValue, lastValue } = this.state;
    const { width, height } = this.props;
    const cardProps = {
      style: {
        width: `${width}rem`,
        height: `${height}rem`,
        marginRight: width / 6 + 'rem'
      },
    };
    const numberStyle = {
      fontSize: `${height * .8}rem`,
      lineHeight: `${height}rem`,
    };
    return (
      <div {...cardProps} className={`${styles.numberCard} item`} >
        <div className={`${styles.card} ${styles.cur} cur`} ref={node => this.card = node}>
          <span className={`${styles.front} front`} style={numberStyle}>{lastValue}</span>
          <span  className={`${styles.back} back`} style={numberStyle}>{nextValue}</span>
        </div>
        <div className={`${styles.card} ${styles.next} next`}>
          <span className={`${styles.front} front`} style={numberStyle}>{lastValue}</span>
          <span className={`${styles.back} back`} style={numberStyle}>{nextValue}</span>
        </div>
      </div>
    );
  }
}